(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[     35914,        750]
NotebookOptionsPosition[     36344,        741]
NotebookOutlinePosition[     36809,        761]
CellTagsIndexPosition[     36766,        758]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 StyleBox["Bending\n",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["Zhelong He, Marek-Jerzy Pindera \nUniversity of Virginia, \
2019-04-13",
  FontSize->16,
  FontColor->GrayLevel[0]]
}], "Title",
 TextAlignment->Center],

Cell["\<\
The following module demonstrates the deformation of a bar section caused by \
pure bending moment. 
Consider a section of bar with square cross section that is marked with \
longitudinal and transverse grid lines. When a pure bending moment is \
applied, the bar will deform in a way shown in the following module. The \
neutral plane or neutral axis will not undergo any deformation in the \
longitudinal direction. When a positive moment is applied, the longitudinal \
line above the neutral axis and below the neutral axis will undergo a \
extension and compression separately, vice versa for a negative moment. The \
transverse line which is originally vertical to the neutral axis will keep to \
be vertical after deformation. \
\>", "Text"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`fac$$ = 2000, $CellContext`opt$$ = 
    1, $CellContext`pers$$ = 0, $CellContext`torque$$ = 20, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`opt$$], 1, 
       Spacer[0]}, {1 -> Text[
         Style["3D Defomation", Bold, 12]], 2 -> Text[
         Style[
          Grid[{{"Deformation Analysis"}}, Alignment -> Left], Bold, 12]]}}, {{
       Hold[$CellContext`torque$$], 20, ""}, -50, 50, 0.1}, {{
       Hold[$CellContext`fac$$], 2000, ""}, 1000, 3000, 1}, {{
       Hold[$CellContext`pers$$], 0, 
       Spacer[0]}, {1 -> Text[
         Style["On", Bold, 12]], 0 -> Text[
         Style["Off", Bold, 12]]}}, {
      Hold[
       Grid[{{
          Manipulate`Place[1]}, {
          PaneSelector[{1 -> Grid[{{
                Text[
                 Style["Applied Moment (MPa)", Bold, 12]], 
                Spacer[5]}, {
                Manipulate`Place[2]}, {
                Text[
                 Style["Deformation Scaling", Bold, 12]]}, {
                Manipulate`Place[3]}, {
                Text[
                 Style["A Beam Slice", Bold, 12]]}, {
                Manipulate`Place[4]}}, Alignment -> Left], 2 -> Grid[{{
                Row[{
                  Text[
                   Style["\[Epsilon]", Bold]], 
                  Text["="], 
                  Text[
                   Style[
                   "\!\(\*UnderscriptBox[\(lim\), \(\[CapitalDelta]s \
\[RightArrow] 0\)]\)", Bold]], 
                  Text[
                   Style[
                   "\!\(\*FractionBox[\(\[CapitalDelta]s' - \
\[CapitalDelta]s\), \(\[CapitalDelta]s\)]\)", Bold, 12]]}, 
                 Spacer[0.5]]}, {
                Row[{
                  Text[
                   Style["\[Epsilon]", Bold, 
                    GrayLevel[1]]], 
                  Text["="], 
                  Text[
                   Style[
                   "\!\(\*UnderscriptBox[\(lim\), \(\[CapitalDelta]\[Theta] \
\[RightArrow] 0\)]\)", Bold]], 
                  Text[
                   Style[
                   "\!\(\*FractionBox[\(\((\[Rho] - y)\) \[CapitalDelta]\
\[Theta] - \[Rho]\[CapitalDelta]\[Theta]\), \
\(\[Rho]\[CapitalDelta]\[Theta]\)]\)", Bold, 12]]}, 
                 Spacer[0.5]]}, {
                Row[{
                  Text[
                   Style["\[Epsilon]", Bold, 
                    GrayLevel[1]]], 
                  Text["="], 
                  Text[
                   Style["-\!\(\*FractionBox[\(y\), \(\[Rho]\)]\)", Bold]]}, 
                 Spacer[0.5]]}}, Alignment -> Left]}, 
           Dynamic[$CellContext`opt$$]]}}, Alignment -> Left, 
        Spacings -> {0, 1}]], Manipulate`Dump`ThisIsNotAControl}}, 
    Typeset`size$$ = {750., {371., 379.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`opt$386028$$ = False, $CellContext`torque$386029$$ = 
    0, $CellContext`fac$386030$$ = 0, $CellContext`pers$386031$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`fac$$ = 2000, $CellContext`opt$$ = 
        1, $CellContext`pers$$ = 0, $CellContext`torque$$ = 20}, 
      "ControllerVariables" :> {
        Hold[$CellContext`opt$$, $CellContext`opt$386028$$, False], 
        Hold[$CellContext`torque$$, $CellContext`torque$386029$$, 0], 
        Hold[$CellContext`fac$$, $CellContext`fac$386030$$, 0], 
        Hold[$CellContext`pers$$, $CellContext`pers$386031$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`inf$, $CellContext`eY$, $CellContext`nu$, \
$CellContext`epsmax$, $CellContext`pho$, $CellContext`theta$, \
$CellContext`cfy$, $CellContext`cfz$, $CellContext`meshstyle$, \
$CellContext`meshcol$, $CellContext`meshopt$, $CellContext`bdstyle$, \
$CellContext`optp$, $CellContext`h$, $CellContext`c$, $CellContext`b$, \
$CellContext`l$, $CellContext`xn$, $CellContext`zn$, $CellContext`x1$, \
$CellContext`x2$, $CellContext`y1$, $CellContext`y2$, $CellContext`z1$, \
$CellContext`z2$, $CellContext`tmax$, $CellContext`dis1$, $CellContext`dis2$, \
$CellContext`conr$, $CellContext`conh$, $CellContext`ptl1$, \
$CellContext`ptl2$, $CellContext`ptl3$, $CellContext`conlb$, \
$CellContext`conlv$, $CellContext`ptr1$, $CellContext`ptr2$, \
$CellContext`ptr3$, $CellContext`conrb$, $CellContext`conrv$, \
$CellContext`nal$, $CellContext`nar$, $CellContext`nuetral$, \
$CellContext`top$, $CellContext`bottom$, $CellContext`left$, \
$CellContext`right$, $CellContext`front$, $CellContext`back$, \
$CellContext`nuetralaxis$, $CellContext`frontp$, $CellContext`backp$, \
$CellContext`arrow$, $CellContext`undeformed$, $CellContext`deformed$, \
$CellContext`indicator$, $CellContext`xu$, $CellContext`r$, $CellContext`t$, \
$CellContext`xd$, $CellContext`ht$, $CellContext`fig0$, $CellContext`fig1$, \
$CellContext`fig2$, $CellContext`fig3$, $CellContext`fig4$, \
$CellContext`fig5$, $CellContext`fig6$, $CellContext`fig7$, \
$CellContext`fig8$, $CellContext`fig9$, $CellContext`fig11$, \
$CellContext`fig12$, $CellContext`fig13$, $CellContext`fig14$, \
$CellContext`fig15$, $CellContext`fig16$}, $CellContext`eY$ = 
         210 10^9; $CellContext`nu$ = 0.3; $CellContext`inf$ = 
         10^15; $CellContext`h$ = 2; $CellContext`c$ = 
         0.5 $CellContext`h$; $CellContext`b$ = 2; $CellContext`l$ = 
         10; $CellContext`z1$ = $CellContext`c$; $CellContext`z2$ = \
-$CellContext`c$; $CellContext`y1$ = (-0.5) $CellContext`b$; $CellContext`y2$ = 
         0.5 $CellContext`b$; $CellContext`x1$ = 
         0.5 $CellContext`l$; $CellContext`x2$ = (-0.5) $CellContext`l$; \
$CellContext`epsmax$ = (($CellContext`fac$$ $CellContext`torque$$) (
            10^6/$CellContext`eY$)) (
           6/($CellContext`b$ $CellContext`h$^2)); $CellContext`pho$ = 
         If[$CellContext`torque$$ != 
           0, $CellContext`c$/$CellContext`epsmax$, $CellContext`inf$]; \
$CellContext`theta$ = $CellContext`l$/$CellContext`pho$; $CellContext`tmax$ = \
$CellContext`l$/$CellContext`pho$; $CellContext`tcut = $CellContext`tmax$/
          10; $CellContext`cfy$ = 5; $CellContext`cfz$ = 
         5; $CellContext`meshstyle$ = 
         If[$CellContext`pers$$ == 0, Full, None]; $CellContext`meshopt$ = 
         If[$CellContext`pers$$ == 0, 1, 0.08]; $CellContext`meshcol$ = 
         If[$CellContext`pers$$ == 0, {}, 
           Lighter[Blue]]; $CellContext`bdstyle$ = 
         If[$CellContext`pers$$ == 0, {}, {
            Thickness[0.0005], Black, Dashed}]; $CellContext`optp$ = 
         0.3; $CellContext`dis1$ = 0.05 $CellContext`l$; $CellContext`dis2$ = 
         0.08 $CellContext`l$; $CellContext`dis3 = 
         0.05 $CellContext`l$; $CellContext`conr$ = 
         0.01 $CellContext`l$; $CellContext`conh$ = 
         0.02 $CellContext`l$; $CellContext`ptl1$ = {$CellContext`pho$ 
            Sin[0.5 $CellContext`theta$] + $CellContext`dis1$ 
            Cos[0.5 $CellContext`theta$] + $CellContext`c$ 
            Sin[0.5 $CellContext`theta$], 
           0, $CellContext`pho$ - $CellContext`pho$ 
           Cos[0.5 $CellContext`theta$] + $CellContext`dis1$ 
            Sin[0.5 $CellContext`theta$] - $CellContext`c$ 
           Cos[0.5 $CellContext`theta$]}; $CellContext`ptl2$ = \
{$CellContext`pho$ Sin[0.5 $CellContext`theta$] + $CellContext`dis2$ 
            Cos[0.5 $CellContext`theta$], 
           0, $CellContext`pho$ - $CellContext`pho$ 
           Cos[0.5 $CellContext`theta$] + $CellContext`dis2$ 
            Sin[0.5 $CellContext`theta$]}; $CellContext`ptl3$ = \
{$CellContext`pho$ Sin[0.5 $CellContext`theta$] + $CellContext`dis1$ 
            Cos[0.5 $CellContext`theta$] - $CellContext`c$ 
           Sin[0.5 $CellContext`theta$], 
           0, $CellContext`pho$ - $CellContext`pho$ 
           Cos[0.5 $CellContext`theta$] + $CellContext`dis1$ 
            Sin[0.5 $CellContext`theta$] + $CellContext`c$ 
            Cos[0.5 $CellContext`theta$]}; $CellContext`conlb$ = 
         If[$CellContext`torque$$ > 
           0, $CellContext`ptl3$, $CellContext`ptl1$]; $CellContext`conlv$ = 
         If[$CellContext`torque$$ > 
           0, $CellContext`ptl3$ + {$CellContext`conh$ 
             Cos[0.5 $CellContext`theta$ + Pi/2 + Pi/20], 
             0, $CellContext`conh$ 
             Sin[0.5 $CellContext`theta$ + Pi/2 + 
               Pi/20]}, $CellContext`ptl1$ + {$CellContext`conh$ 
             Cos[(-0.5) Abs[$CellContext`theta$] - Pi/2 - Pi/20], 
             0, $CellContext`conh$ 
             Sin[(-0.5) Abs[$CellContext`theta$] - Pi/2 - Pi/
               20]}]; $CellContext`ptr1$ = {(-$CellContext`pho$) 
            Sin[0.5 $CellContext`theta$] - $CellContext`dis1$ 
           Cos[0.5 $CellContext`theta$] - $CellContext`c$ 
           Sin[0.5 $CellContext`theta$], 
           0, $CellContext`pho$ - $CellContext`pho$ 
           Cos[0.5 $CellContext`theta$] + $CellContext`dis1$ 
            Sin[0.5 $CellContext`theta$] - $CellContext`c$ 
           Cos[0.5 $CellContext`theta$]}; $CellContext`ptr2$ = \
{(-$CellContext`pho$) Sin[0.5 $CellContext`theta$] - $CellContext`dis2$ 
           Cos[0.5 $CellContext`theta$], 
           0, $CellContext`pho$ - $CellContext`pho$ 
           Cos[0.5 $CellContext`theta$] + $CellContext`dis2$ 
            Sin[0.5 $CellContext`theta$]}; $CellContext`ptr3$ = \
{(-$CellContext`pho$) Sin[0.5 $CellContext`theta$] - $CellContext`dis1$ 
           Cos[0.5 $CellContext`theta$] + $CellContext`c$ 
            Sin[0.5 $CellContext`theta$], 
           0, $CellContext`pho$ - $CellContext`pho$ 
           Cos[0.5 $CellContext`theta$] + $CellContext`dis1$ 
            Sin[0.5 $CellContext`theta$] + $CellContext`c$ 
            Cos[0.5 $CellContext`theta$]}; $CellContext`conrb$ = 
         If[$CellContext`torque$$ > 
           0, $CellContext`ptr3$, $CellContext`ptr1$]; $CellContext`conrv$ = 
         If[$CellContext`torque$$ > 
           0, $CellContext`ptr3$ + {$CellContext`conh$ 
             Cos[Pi/2 - 0.5 $CellContext`theta$ - Pi/20], 
             0, $CellContext`conh$ 
             Sin[Pi/2 - 0.5 $CellContext`theta$ - Pi/
               20]}, $CellContext`ptr1$ + {$CellContext`conh$ 
             Cos[0.5 Abs[$CellContext`theta$] - Pi/2 + Pi/20], 
             0, $CellContext`conh$ 
             Sin[0.5 Abs[$CellContext`theta$] - Pi/2 + 
               Pi/20]}]; $CellContext`nal$ = {$CellContext`pho$ 
            Sin[0.5 $CellContext`theta$] + $CellContext`dis3 
            Cos[0.5 $CellContext`theta$], 
           0, $CellContext`pho$ - $CellContext`pho$ 
           Cos[0.5 $CellContext`theta$] + $CellContext`dis3 
            Sin[0.5 $CellContext`theta$]}; $CellContext`nar$ = \
{(-$CellContext`pho$) Sin[0.5 $CellContext`theta$] - $CellContext`dis3 
           Cos[0.5 $CellContext`theta$], 
           0, $CellContext`pho$ - $CellContext`pho$ 
           Cos[0.5 $CellContext`theta$] + $CellContext`dis3 
            Sin[0.5 $CellContext`theta$]}; $CellContext`xn$ = \
$CellContext`pho$ 
          Sin[$CellContext`t$]; $CellContext`zn$ = $CellContext`pho$ - \
$CellContext`pho$ 
          Cos[$CellContext`t$]; $CellContext`nuetral$ = {$CellContext`xn$, \
$CellContext`y, $CellContext`zn$}; $CellContext`top$ = {($CellContext`pho$ - \
$CellContext`z1$) 
           Sin[$CellContext`t$], $CellContext`y + ((($CellContext`cfy$ \
$CellContext`nu$) $CellContext`y) ($CellContext`z1$/$CellContext`c$)) \
$CellContext`epsmax$, $CellContext`z1$ + ($CellContext`pho$ - \
$CellContext`z1$) (1 - 
             Cos[$CellContext`t$]) - (($CellContext`cfz$ \
($CellContext`nu$/$CellContext`c$)) $CellContext`epsmax$) $CellContext`y^2}; \
$CellContext`bottom$ = {($CellContext`pho$ - $CellContext`z2$) 
           Sin[$CellContext`t$], $CellContext`y + ((($CellContext`cfy$ \
$CellContext`nu$) $CellContext`y) ($CellContext`z2$/$CellContext`c$)) \
$CellContext`epsmax$, $CellContext`z2$ + ($CellContext`pho$ - \
$CellContext`z2$) (1 - 
             Cos[$CellContext`t$]) - (($CellContext`cfz$ \
($CellContext`nu$/$CellContext`c$)) $CellContext`epsmax$) $CellContext`y^2}; \
$CellContext`left$ = {($CellContext`pho$ - $CellContext`z) 
           Sin[$CellContext`t$], $CellContext`y1$ + ((($CellContext`cfy$ \
$CellContext`nu$) $CellContext`z) ($CellContext`y1$/$CellContext`c$)) \
$CellContext`epsmax$, $CellContext`z + ($CellContext`pho$ - $CellContext`z) (
             1 - Cos[$CellContext`t$]) - (($CellContext`cfz$ \
($CellContext`nu$/$CellContext`c$)) $CellContext`epsmax$) $CellContext`y1$^2}; \
$CellContext`right$ = {($CellContext`pho$ - $CellContext`z) 
           Sin[$CellContext`t$], $CellContext`y2$ + ((($CellContext`cfy$ \
$CellContext`nu$) $CellContext`z) ($CellContext`y2$/$CellContext`c$)) \
$CellContext`epsmax$, $CellContext`z + ($CellContext`pho$ - $CellContext`z) (
             1 - Cos[$CellContext`t$]) - (($CellContext`cfz$ \
($CellContext`nu$/$CellContext`c$)) $CellContext`epsmax$) $CellContext`y2$^2}; \
$CellContext`front$ = {($CellContext`pho$ - $CellContext`z) 
           Sin[$CellContext`tmax$/
             2], $CellContext`y + ((($CellContext`cfy$ $CellContext`nu$) \
$CellContext`y) ($CellContext`z/$CellContext`c$)) $CellContext`epsmax$, \
$CellContext`z + ($CellContext`pho$ - $CellContext`z) (1 - 
             Cos[$CellContext`tmax$/
              2]) - (($CellContext`cfz$ ($CellContext`nu$/$CellContext`c$)) \
$CellContext`epsmax$) $CellContext`y^2}; $CellContext`back$ = \
{($CellContext`pho$ - $CellContext`z) 
           Sin[(-$CellContext`tmax$)/
             2], $CellContext`y + ((($CellContext`cfy$ $CellContext`nu$) \
$CellContext`y) ($CellContext`z/$CellContext`c$)) $CellContext`epsmax$, \
$CellContext`z + ($CellContext`pho$ - $CellContext`z) (1 - 
             Cos[(-$CellContext`tmax$)/
              2]) - (($CellContext`cfz$ ($CellContext`nu$/$CellContext`c$)) \
$CellContext`epsmax$) $CellContext`y^2}; $CellContext`arrow$ = {
           Thickness[0.003], 
           Darker[Blue], 
           
           BSplineCurve[{$CellContext`ptl1$, $CellContext`ptl2$, \
$CellContext`ptl3$}], 
           
           BSplineCurve[{$CellContext`ptr1$, $CellContext`ptr2$, \
$CellContext`ptr3$}], 
           If[$CellContext`torque$$ != 0, {
             
             Cone[{$CellContext`conlb$, $CellContext`conlv$}, \
$CellContext`conr$], 
             
             Cone[{$CellContext`conrb$, $CellContext`conrv$}, \
$CellContext`conr$]}]}; $CellContext`nuetralaxis$ = {$CellContext`xn$, 
           0, $CellContext`zn$}; $CellContext`frontp$ = {($CellContext`pho$ - \
$CellContext`z) 
           Sin[$CellContext`tcut/
             2], $CellContext`y + ((($CellContext`cfy$ $CellContext`nu$) \
$CellContext`y) ($CellContext`z/$CellContext`c$)) $CellContext`epsmax$, \
$CellContext`z + ($CellContext`pho$ - $CellContext`z) (1 - 
             Cos[$CellContext`tcut/
              2]) - (($CellContext`cfz$ ($CellContext`nu$/$CellContext`c$)) \
$CellContext`epsmax$) $CellContext`y^2}; $CellContext`backp$ = \
{($CellContext`pho$ - $CellContext`z) 
           Sin[(-$CellContext`tcut)/
             2], $CellContext`y + ((($CellContext`cfy$ $CellContext`nu$) \
$CellContext`y) ($CellContext`z/$CellContext`c$)) $CellContext`epsmax$, \
$CellContext`z + ($CellContext`pho$ - $CellContext`z) (1 - 
             Cos[(-$CellContext`tcut)/
              2]) - (($CellContext`cfz$ ($CellContext`nu$/$CellContext`c$)) \
$CellContext`epsmax$) $CellContext`y^2}; $CellContext`xu$ = -3.5; \
$CellContext`undeformed$ = {
           Opacity[0.5], 
           Lighter[Blue], 
           Rectangle[{$CellContext`xu$, -1}, {$CellContext`xu$ + 1, 1}], 
           Opacity[1], 
           Thickness[0.0025], 
           Darker[Red], 
           
           Line[{{$CellContext`xu$ + 0.01, 0.5}, {$CellContext`xu$ + 0.98, 
              0.5}}], Black, 
           Line[{{$CellContext`xu$ - 0.01, 0}, {$CellContext`xu$ + 0.98, 0}}], 
           Thickness[0.001], 
           Line[{{$CellContext`xu$ - 0.5, 0}, {$CellContext`xu$ - 0.1, 0}}], 
           
           Line[{{$CellContext`xu$ - 0.5, 0.5}, {$CellContext`xu$ - 0.1, 
              0.5}}], 
           Arrowheads[0.01], 
           
           Arrow[{{$CellContext`xu$ - 0.3, 0}, {$CellContext`xu$ - 0.3, 
              0.5}}], 
           Text[
            Style["y", Bold, 9, Italic], {$CellContext`xu$ - 0.45, 0.25}], 
           
           Line[{{$CellContext`xu$ + 0.7, 0}, {$CellContext`xu$ + 
              1.2, -0.5}}], 
           Line[{{$CellContext`xu$ + 0.7, 0.5}, {$CellContext`xu$ + 1.2, 1}}], 
           Text[
            Style[
            "\[CapitalDelta]x", Bold, 9], {$CellContext`xu$ + 1.4, -0.6}], 
           Text[
            Style[
            "\[CapitalDelta]s = \[CapitalDelta]x", Bold, 
             9], {$CellContext`xu$ + 1.6, 1.1}], 
           Text[
            Style[
            "NA", Bold, 9], {$CellContext`xu$ + 1.2, 0}]}; $CellContext`r$ = 
         5; $CellContext`t$ = 1/(2 ($CellContext`r$ - 1)); $CellContext`xd$ = 
         2.4; $CellContext`deformed$ = {
           EdgeForm[White], 
           Opacity[0.5], 
           Lighter[Blue], 
           
           Disk[{$CellContext`xd$, $CellContext`r$ - 1}, $CellContext`r$, {
            1.5 Pi - $CellContext`t$, 1.5 Pi + $CellContext`t$}], 
           Opacity[1], 
           FaceForm[White], 
           
           Disk[{$CellContext`xd$, $CellContext`r$ - 1}, $CellContext`r$ - 
            2, {1.5 Pi - $CellContext`t$, 1.5 Pi + $CellContext`t$}], 
           Thickness[0.0025], 
           Darker[Red], 
           
           Circle[{$CellContext`xd$, $CellContext`r$ - 1}, $CellContext`r$ - 
            1.5, {1.5 Pi - 0.98 $CellContext`t$, 1.5 Pi + 
             0.98 $CellContext`t$}], Black, 
           
           Circle[{$CellContext`xd$, $CellContext`r$ - 1}, $CellContext`r$ - 
            1, {1.5 Pi - 0.98 $CellContext`t$, 1.5 Pi + 
             0.98 $CellContext`t$}], 
           Arrowheads[0.015], 
           
           Arrow[{{$CellContext`xd$, $CellContext`r$ - 
              1}, {$CellContext`xd$, $CellContext`r$ - 1} + ($CellContext`r$ - 
               1) {
                Sin[$CellContext`t$], -Cos[$CellContext`t$]}}], 
           
           Arrow[{{$CellContext`xd$, $CellContext`r$ - 
              1}, {$CellContext`xd$, $CellContext`r$ - 1} + ($CellContext`r$ - 
               1) {-Sin[$CellContext`t$], -Cos[$CellContext`t$]}}], Black, 
           Thickness[0.0015], 
           
           Circle[{$CellContext`xd$, $CellContext`r$ - 1}, $CellContext`r$ - 
            1, {1.5 Pi - 1.2 $CellContext`t$, 1.5 Pi - 1.7 $CellContext`t$}], 
           
           Circle[{$CellContext`xd$, $CellContext`r$ - 1}, $CellContext`r$ - 
            1.5, {1.5 Pi - 1.2 $CellContext`t$, 1.5 Pi - 
             1.7 $CellContext`t$}], 
           Arrowheads[0.01], 
           
           Arrow[{{$CellContext`xd$, $CellContext`r$ - 1} + ($CellContext`r$ - 
               1) {
                Cos[1.5 Pi - 1.4 $CellContext`t$], 
                Sin[
                1.5 Pi - 
                 1.4 $CellContext`t$]}, {$CellContext`xd$, $CellContext`r$ - 
               1} + ($CellContext`r$ - 1.5) {
                Cos[1.5 Pi - 1.4 $CellContext`t$], 
                Sin[1.5 Pi - 1.4 $CellContext`t$]}}], 
           Thickness[0.003], 
           Arrowheads[0.02], 
           Darker[Red], 
           Arrow[
            Map[N[
              Table[{
                  Cos[$CellContext`k], 
                  Sin[$CellContext`k]} Part[#, 2] + 
               Part[#, 1], {$CellContext`k, 
                Part[#, 3], 
                Part[#, 4], (Part[#, 4] - Part[#, 3])/
                Part[#, 5]}]]& , {{{$CellContext`xd$ - 0.6, 0.3}, 0.8, 1.15 
               Pi, 0.7 Pi, 100}}]], 
           Arrow[
            Map[N[
              Table[{
                  Cos[$CellContext`k], 
                  Sin[$CellContext`k]} Part[#, 2] + 
               Part[#, 1], {$CellContext`k, 
                Part[#, 3], 
                Part[#, 4], (Part[#, 4] - Part[#, 3])/
                Part[#, 5]}]]& , {{{$CellContext`xd$ + 0.6, 0.3}, 
               0.8, (-0.15) Pi, 0.3 Pi, 100}}]], Black, 
           Thickness[0.0015], 
           Arrowheads[{-0.01, 0.01}], 
           Arrow[
            Map[N[
              Table[{
                  Cos[$CellContext`k], 
                  Sin[$CellContext`k]} Part[#, 2] + 
               Part[#, 1], {$CellContext`k, 
                Part[#, 3], 
                Part[#, 4], (Part[#, 4] - Part[#, 3])/
                Part[#, 5]}]]& , {{{$CellContext`xd$, $CellContext`r$ - 1}, 
               1.5, 1.5 Pi - $CellContext`t$, 1.5 Pi + $CellContext`t$, 
               100}}]], 
           
           Line[{{$CellContext`xd$, $CellContext`r$ - 2.5}, {$CellContext`xd$ + 
              0.5, $CellContext`r$ - 3.}}], 
           
           Line[{{$CellContext`xd$, $CellContext`r$ - 1} + ($CellContext`r$ - 
               1.5) {
                Cos[1.5 Pi + Pi/40], 
                Sin[1.5 Pi + Pi/40]}, {$CellContext`xd$, $CellContext`r$ - 
               1} + ($CellContext`r$ - 1.5) {
                Cos[1.5 Pi + Pi/40], 
                Sin[1.5 Pi + Pi/40]} + {0.3, 0.3}}], 
           
           Line[{{$CellContext`xd$, $CellContext`r$ - 1} + ($CellContext`r$ - 
               1) {
                Cos[1.5 Pi + Pi/40], 
                Sin[1.5 Pi + Pi/40]}, {$CellContext`xd$, $CellContext`r$ - 
               1} + ($CellContext`r$ - 1) {
                Cos[1.5 Pi + Pi/40], 
                Sin[1.5 Pi + Pi/40]} + {0.4, -0.4}}], 
           PointSize[0.008], 
           Point[{$CellContext`xd$, $CellContext`r$ - 1}], 
           Text[
            Style[
            "O'", Bold, 9, Italic], {$CellContext`xd$ + 0.3, $CellContext`r$ - 
             1}], 
           Text[
            Style[
            "\[CapitalDelta]\[Theta]", Bold, 9], {$CellContext`xd$ + 
             0.67, $CellContext`r$ - 3.17}], 
           Text[
            Style[
            "\[CapitalDelta]s'", Bold, 
             9], {$CellContext`xd$, $CellContext`r$ - 1} + ($CellContext`r$ - 
              1.5) {
               Cos[1.5 Pi + Pi/40], 
               Sin[1.5 Pi + Pi/40]} + {0.45, 0.45}], 
           Text[
            Style[
            "\[CapitalDelta]x", Bold, 
             9], {$CellContext`xd$, $CellContext`r$ - 1} + ($CellContext`r$ - 
              1) {
               Cos[1.5 Pi + Pi/40], 
               Sin[1.5 Pi + Pi/40]} + {0.55, -0.55}], 
           Text[
            Style[
            "y", Bold, 9, 
             Italic], {$CellContext`xd$, $CellContext`r$ - 
              1} + ($CellContext`r$ - 1.25) {
               Cos[1.5 Pi - 1.6 $CellContext`t$], 
               Sin[1.5 Pi - 1.6 $CellContext`t$]}], 
           Text[
            Style[
            "\[Rho]", Bold, 
             9], {$CellContext`xd$, $CellContext`r$ - 1} + ($CellContext`r$ - 
              3) {
               Cos[1.5 Pi - 1.5 $CellContext`t$], 
               Sin[1.5 Pi - 1.5 $CellContext`t$]}], 
           Text[
            Style["M", Bold, 9], {$CellContext`xd$ - 1.6, 0.5}], 
           Text[
            Style["M", Bold, 9], {$CellContext`xd$ + 1.6, 0.5}], 
           Text[
            Style[
            "NA", Bold, 9], {$CellContext`xd$ + 0.7, 
             0.05}]}; $CellContext`ht$ = 0.06; $CellContext`indicator$ = {
           FaceForm[Gray], 
           
           Rectangle[{$CellContext`xu$ + 
             2.1, -$CellContext`ht$}, {$CellContext`xu$ + 
             3.6, $CellContext`ht$}], 
           
           Triangle[{{$CellContext`xu$ + 
              3.6, (-1.3) $CellContext`ht$}, {$CellContext`xu$ + 3.6, 
              1.3 $CellContext`ht$}, {$CellContext`xu$ + 3.9, 0}}], 
           Text[
            Style[
             Grid[{{"Before"}, {"deformation"}}], Bold, 
             12], {$CellContext`xu$ + 0.5, -1.75}], 
           Text[
            Style[
             Grid[{{"After"}, {"deformation"}}], Bold, 
             12], {$CellContext`xd$, -1.75}]}; $CellContext`fig0$ = 
         ParametricPlot3D[$CellContext`nuetral$, {$CellContext`t$, \
(-$CellContext`tmax$)/2, $CellContext`tmax$/
            2}, {$CellContext`y, (-$CellContext`b$)/2, $CellContext`b$/
            2}]; $CellContext`fig1$ = 
         ParametricPlot3D[$CellContext`top$, {$CellContext`t$, \
(-$CellContext`tmax$)/2, $CellContext`tmax$/
            2}, {$CellContext`y, (-$CellContext`b$)/2, $CellContext`b$/2}, 
           PlotRange -> {{(-0.7) $CellContext`l$, 
              0.7 $CellContext`l$}, {-$CellContext`b$, $CellContext`b$}, \
{(-2.5) $CellContext`h$, 2.5 $CellContext`h$}}, SphericalRegion -> True, 
           Boxed -> False, Axes -> False, Ticks -> None, 
           ImageSize -> {500, 500}, ViewAngle -> 0.3407, 
           ViewPoint -> {0.7858, -3.1425, 0.978}, 
           ViewVertical -> {0.0734, -1.2171, 1.7681}, 
           Mesh -> $CellContext`meshstyle$, PlotStyle -> Directive[
             Opacity[$CellContext`meshopt$], $CellContext`meshcol$], 
           BoundaryStyle -> $CellContext`bdstyle$]; $CellContext`fig2$ = 
         ParametricPlot3D[$CellContext`bottom$, {$CellContext`t$, \
(-$CellContext`tmax$)/2, $CellContext`tmax$/
            2}, {$CellContext`y, (-$CellContext`b$)/2, $CellContext`b$/2}, 
           Mesh -> $CellContext`meshstyle$, PlotStyle -> Directive[
             Opacity[$CellContext`meshopt$], $CellContext`meshcol$], 
           BoundaryStyle -> $CellContext`bdstyle$]; $CellContext`fig3$ = 
         ParametricPlot3D[$CellContext`left$, {$CellContext`t$, \
(-$CellContext`tmax$)/2, $CellContext`tmax$/
            2}, {$CellContext`z, -$CellContext`c$, $CellContext`c$}, 
           Mesh -> $CellContext`meshstyle$, PlotStyle -> Directive[
             Opacity[$CellContext`meshopt$], $CellContext`meshcol$], 
           BoundaryStyle -> $CellContext`bdstyle$]; $CellContext`fig4$ = 
         ParametricPlot3D[$CellContext`right$, {$CellContext`t$, \
(-$CellContext`tmax$)/2, $CellContext`tmax$/
            2}, {$CellContext`z, -$CellContext`c$, $CellContext`c$}, 
           Mesh -> $CellContext`meshstyle$, PlotStyle -> Directive[
             Opacity[$CellContext`meshopt$], $CellContext`meshcol$], 
           BoundaryStyle -> $CellContext`bdstyle$]; $CellContext`fig5$ = 
         ParametricPlot3D[$CellContext`front$, {$CellContext`y, \
(-$CellContext`b$)/2, $CellContext`b$/
            2}, {$CellContext`z, -$CellContext`c$, $CellContext`c$}, 
           Mesh -> $CellContext`meshstyle$, PlotStyle -> Directive[
             Opacity[$CellContext`meshopt$], $CellContext`meshcol$], 
           BoundaryStyle -> $CellContext`bdstyle$]; $CellContext`fig6$ = 
         ParametricPlot3D[$CellContext`back$, {$CellContext`y, \
(-$CellContext`b$)/2, $CellContext`b$/
            2}, {$CellContext`z, -$CellContext`c$, $CellContext`c$}, 
           Mesh -> $CellContext`meshstyle$, PlotStyle -> Directive[
             Opacity[$CellContext`meshopt$], $CellContext`meshcol$], 
           BoundaryStyle -> $CellContext`bdstyle$]; $CellContext`fig7$ = 
         If[$CellContext`pers$$ == 0, 
           Graphics3D[
            If[$CellContext`torque$$ != 0, $CellContext`arrow$]], {
            
            ParametricPlot3D[$CellContext`nuetralaxis$, {$CellContext`t$, \
(-$CellContext`tmax$)/2, $CellContext`tmax$/2}, PlotStyle -> Directive[Black, 
               Thickness[0.003]]], 
            Graphics3D[{
              Text[
               Style["NA", Bold, 9], $CellContext`nal$], 
              Text[
               Style[
               "NA", Bold, 9], $CellContext`nar$]}]}]; $CellContext`fig11$ = 
         ParametricPlot3D[$CellContext`top$, {$CellContext`t$, \
(-$CellContext`tcut)/2, $CellContext`tcut/
            2}, {$CellContext`y, (-$CellContext`b$)/2, $CellContext`b$/2}, 
           Mesh -> None, PlotStyle -> Directive[
             Opacity[$CellContext`optp$], Blue]]; $CellContext`fig12$ = 
         ParametricPlot3D[$CellContext`bottom$, {$CellContext`t$, \
(-$CellContext`tcut)/2, $CellContext`tcut/
            2}, {$CellContext`y, (-$CellContext`b$)/2, $CellContext`b$/2}, 
           Mesh -> None, PlotStyle -> Directive[
             Opacity[$CellContext`optp$], Blue]]; $CellContext`fig13$ = 
         ParametricPlot3D[$CellContext`left$, {$CellContext`t$, \
(-$CellContext`tcut)/2, $CellContext`tcut/
            2}, {$CellContext`z, -$CellContext`c$, $CellContext`c$}, Mesh -> 
           None, PlotStyle -> Directive[
             Opacity[$CellContext`optp$], Blue]]; $CellContext`fig14$ = 
         ParametricPlot3D[$CellContext`right$, {$CellContext`t$, \
(-$CellContext`tcut)/2, $CellContext`tcut/
            2}, {$CellContext`z, -$CellContext`c$, $CellContext`c$}, Mesh -> 
           None, PlotStyle -> Directive[
             Opacity[$CellContext`optp$], Blue]]; $CellContext`fig15$ = 
         ParametricPlot3D[$CellContext`frontp$, {$CellContext`y, \
(-$CellContext`b$)/2, $CellContext`b$/
            2}, {$CellContext`z, -$CellContext`c$, $CellContext`c$}, Mesh -> 
           None, PlotStyle -> Directive[
             Opacity[$CellContext`optp$], Blue], 
           BoundaryStyle -> $CellContext`bdstyle$]; $CellContext`fig16$ = 
         ParametricPlot3D[$CellContext`backp$, {$CellContext`y, \
(-$CellContext`b$)/2, $CellContext`b$/
            2}, {$CellContext`z, -$CellContext`c$, $CellContext`c$}, Mesh -> 
           None, PlotStyle -> Directive[
             Opacity[$CellContext`optp$], Blue], 
           BoundaryStyle -> $CellContext`bdstyle$]; $CellContext`fig8$ = 
         If[$CellContext`pers$$ == 
           0, {}, {$CellContext`fig11$, $CellContext`fig12$, \
$CellContext`fig13$, $CellContext`fig14$, $CellContext`fig15$, \
$CellContext`fig16$}]; $CellContext`fig9$ = 
         Graphics[{$CellContext`undeformed$, $CellContext`deformed$, \
$CellContext`indicator$}, PlotRange -> {{-5, 5}, {-5, 5}}, Axes -> False, 
           Ticks -> None, ImageSize -> {500, 500}]; 
        Switch[$CellContext`opt$$, 1, 
          
          Show[$CellContext`fig1$, $CellContext`fig2$, $CellContext`fig3$, \
$CellContext`fig4$, $CellContext`fig5$, $CellContext`fig6$, \
$CellContext`fig7$, $CellContext`fig8$], 2, $CellContext`fig9$]], 
      "Specifications" :> {{{$CellContext`opt$$, 1, 
          Spacer[0]}, {1 -> Text[
            Style["3D Defomation", Bold, 12]], 2 -> Text[
            Style[
             Grid[{{"Deformation Analysis"}}, Alignment -> Left], Bold, 12]]},
          Appearance -> "Vertical", ControlType -> RadioButton, 
         ControlPlacement -> 1}, {{$CellContext`torque$$, 20, ""}, -50, 50, 
         0.1, Appearance -> "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         2}, {{$CellContext`fac$$, 2000, ""}, 1000, 3000, 1, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         3}, {{$CellContext`pers$$, 0, 
          Spacer[0]}, {1 -> Text[
            Style["On", Bold, 12]], 0 -> Text[
            Style["Off", Bold, 12]]}, ControlType -> RadioButton, 
         ControlPlacement -> 4}, 
        Grid[{{
           Manipulate`Place[1]}, {
           PaneSelector[{1 -> Grid[{{
                 Text[
                  Style["Applied Moment (MPa)", Bold, 12]], 
                 Spacer[5]}, {
                 Manipulate`Place[2]}, {
                 Text[
                  Style["Deformation Scaling", Bold, 12]]}, {
                 Manipulate`Place[3]}, {
                 Text[
                  Style["A Beam Slice", Bold, 12]]}, {
                 Manipulate`Place[4]}}, Alignment -> Left], 2 -> Grid[{{
                 Row[{
                   Text[
                    Style["\[Epsilon]", Bold]], 
                   Text["="], 
                   Text[
                    Style[
                    "\!\(\*UnderscriptBox[\(lim\), \(\[CapitalDelta]s \
\[RightArrow] 0\)]\)", Bold]], 
                   Text[
                    Style[
                    "\!\(\*FractionBox[\(\[CapitalDelta]s' - \[CapitalDelta]s\
\), \(\[CapitalDelta]s\)]\)", Bold, 12]]}, 
                  Spacer[0.5]]}, {
                 Row[{
                   Text[
                    Style["\[Epsilon]", Bold, 
                    GrayLevel[1]]], 
                   Text["="], 
                   Text[
                    Style[
                    "\!\(\*UnderscriptBox[\(lim\), \(\[CapitalDelta]\[Theta] \
\[RightArrow] 0\)]\)", Bold]], 
                   Text[
                    Style[
                    "\!\(\*FractionBox[\(\((\[Rho] - y)\) \[CapitalDelta]\
\[Theta] - \[Rho]\[CapitalDelta]\[Theta]\), \
\(\[Rho]\[CapitalDelta]\[Theta]\)]\)", Bold, 12]]}, 
                  Spacer[0.5]]}, {
                 Row[{
                   Text[
                    Style["\[Epsilon]", Bold, 
                    GrayLevel[1]]], 
                   Text["="], 
                   Text[
                    Style["-\!\(\*FractionBox[\(y\), \(\[Rho]\)]\)", Bold]]}, 
                  Spacer[0.5]]}}, Alignment -> Left]}, 
            Dynamic[$CellContext`opt$$]]}}, Alignment -> Left, 
         Spacings -> {0, 1}]}, "Options" :> {ControlPlacement -> Left}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{1053., {416., 425.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 TextAlignment->Center]
}, Open  ]]
},
WindowSize->{1920, 997},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
CellContext->Notebook,
TrackCellChangeTimes->False,
Magnification:>1.5 Inherited,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 235, 8, 230, "Title"],
Cell[1724, 45, 757, 12, 159, "Text"],
Cell[2484, 59, 33844, 679, 865, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature kxT4ww7a8qhXmD1IMkaWQm1S *)
